data(PimaIndiansDiabetes)
data(PimaIndiansDiabetes2)PimaIndiansDiabetes2 contains a corrected
version of the original data set. While the UCI repository index
claims that there are no missing values, closer inspection of the data
shows several physical impossibilities, e.g., blood pressure or body
mass index of 0. In PimaIndiansDiabetes2, all zero values of
glucose, pressure, triceps, insulin and
mass have been set to NA, see also Wahba et al (1995)
and Ripley (1996).Brian D. Ripley (1996), Pattern Recognition and Neural Networks, Cambridge University Press, Cambridge. Grace Whaba, Chong Gu, Yuedong Wang, and Richard Chappell (1995), Soft Classification a.k.a. Risk Estimation via Penalized Log Likelihood and Smoothing Spline Analysis of Variance, in D. H. Wolpert (1995), The Mathematics of Generalization, 331-359, Addison-Wesley, Reading, MA.
data(PimaIndiansDiabetes)
summary(PimaIndiansDiabetes)
data(PimaIndiansDiabetes2)
summary(PimaIndiansDiabetes2)Run the code above in your browser using DataLab