Servo: Servo Data

ServoR Documentation

Servo Data

Description

This data set is from a simulation of a servo system involving a servo amplifier, a motor, a lead screw/nut, and a sliding carriage of some sort. It may have been on of the translational axes of a robot on the 9th floor of the AI lab. In any case, the output value is almost certainly a rise time, or the time required for the system to respond to a step change in a position set point. The variables that describe the data set and their values are the following:

[,1] Motor A,B,C,D,E
[,2] Screw A,B,C,D,E
[,3] Pgain 3,4,5,6
[,4] Vgain 1,2,3,4,5
[,5] Class 0.13 to 7.10

Usage

data("Servo", package = "mlbench")

Format

A data frame with 167 observations on 5 variables, 4 nominal and 1 as the target class.

  • Creator: Karl Ulrich (MIT) in 1986

  • Donor: Ross Quinlan

These data have been taken from the UCI Repository Of Machine Learning Databases \bibcitepBlake+Merz:1998 and were converted to R format by Evgenia Dimitriadou in the late 1990s.

The current version of the UC Irvine Machine Learning Repository Servo data set is available from \Sexpr[results=rd]{tools:::Rd_expr_doi("10.24432/C5Q30F")}.

References

\bibshow

Quinlan:1992, Quinlan:1993, Blake+Merz:1998

Examples

data("Servo", package = "mlbench")
summary(Servo)

mlbench documentation built on March 26, 2026, 5:09 p.m.

Related to Servo in mlbench...