SynthDiabetes: Synthetic Diabetes Database

SynthDiabetesR Documentation

Synthetic Diabetes Database

Description

A data frame for a synthetic diabetes case study with 768 observations on 9 variables.

Usage

data("SynthDiabetes", package = "mlbench")
data("SynthDiabetes2", package = "mlbench")

Format

pregnant Number of times pregnant
glucose Plasma glucose concentration (glucose tolerance test)
pressure Diastolic blood pressure (mm Hg)
triceps Triceps skin fold thickness (mm)
insulin 2-hour serum insulin (mu U/ml)
mass Body mass index
pedigree Diabetes pedigree function
age Age (years)
diabetes Class variable (test for diabetes)

Details

This synthetic diabetes database has been created by Matthias Templ to mimic the data analyzed by \bibcitetSmith+Everhart+Dickson:1988. Every value of the data is synthetic and no row corresponds to a real person.

The original data were collected by the National Institute of Diabetes and Digestive and Kidney Diseases (NIDDK) and had apparently been included without informed consent in earlier versions of the UCI Repository Of Machine Learning Databases \bibcitepBlake+Merz:1998 and the mlbench package (under the name PimaIndiansDiabetes and PimaIndiansDiabetes2). Both the UCI repository and mlbench ceased distributing the original data when made aware that the data had most likely been shared illicitly.

The original data contained some measurements that were physically impossible (e.g., blood pressure or body mass index of 0) and that were later treated as missing values, see \bibcitetWahba+Gu+Wang:1995 and \bibcitetRipley:1996. The data set SynthDiabetes2 mimics the pattern of the missing values while in SynthDiabetes, all NA values for glucose, pressure, triceps, insulin, and mass have been set to zero.

Synthetic data generated by Matthias Templ using sequential robust synthesis with a random-forest backend and the missingness pattern treated as a structural variable. Every value of the data is synthetic and no row corresponds to a real person.

References

\bibshow

Blake+Merz:1998, Ripley:1996, Smith+Everhart+Dickson:1988, Wahba+Gu+Wang:1995

Examples

data("SynthDiabetes", package = "mlbench")
summary(SynthDiabetes)

data("SynthDiabetes2", package = "mlbench")
summary(SynthDiabetes2)

## missingness pattern
colSums(is.na(SynthDiabetes2))

## logistic regression for diabetes classification
m <- glm(diabetes ~ ., data = SynthDiabetes2, family = binomial)
summary(m)

mlbench documentation built on Aug. 15, 2026, 1:06 a.m.