This synthetic diabetes database has been created by Matthias Templ
to mimic the data analyzed by Smith+Everhart+Dickson:1988.
Every value of the data is synthetic and no row corresponds to a real
person.
The original data were collected by the National Institute of Diabetes
and Digestive and Kidney Diseases (NIDDK) and had apparently been
included without informed consent in earlier versions of the UCI
Repository Of Machine Learning Databases Blake+Merz:1998
and the mlbench package (under the name
PimaIndiansDiabetes and PimaIndiansDiabetes2).
Both the UCI repository and mlbench ceased distributing the
original data when made aware that the data had most likely been
shared illicitly.
The original data contained some measurements that were physically
impossible (e.g., blood pressure or body mass index of 0) and that
were later treated as missing values, see
Wahba+Gu+Wang:1995 and Ripley:1996. The data
set SynthDiabetes2 mimics the pattern of the missing values
while in SynthDiabetes, all NA values for
glucose, pressure, triceps, insulin, and
mass have been set to zero.